@@ -86,7 +86,7 @@
 #define KARCHIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KARCHIVE_NO_DEPRECATED
-#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
+#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
 #endif
 #ifdef KARCHIVE_NO_DEPRECATED_WARNINGS
 #  define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KARCHIVE_DEPRECATED_WARNINGS_SINCE KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x54600
+#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x54a00
 #  endif
 #endif
 
@@ -117,5 +117,6 @@
 #endif
 #define KARCHIVE_DEPRECATED_VERSION_5(minor, text)      KARCHIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KARCHIVE_DEPRECATED_VERSION(major, minor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KARCHIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KARCHIVE_EXPORT_H */
